package com.chinaitop.depot.system.controller;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;

import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.chinaitop.depot.system.model.BizUnitInfo;
import com.chinaitop.depot.system.service.UnitInfoService;
import com.github.pagehelper.PageInfo;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

/**
 * 单位信息控制类
 * 查询省平台数据库
 *
 */
@RestController
@RequestMapping(value="/unitInfo")
@Api(value= "UnitInfoController", description = "单位信息控制类")
public class UnitInfoController {
	
	@Resource
	private UnitInfoService unitInfoService;

	
	/**
     * 单位信息列表
     * @param pageNum  页码
     * @param pageSize 每页显示条数
     * @return
     * @throws Exception
     */
    @RequestMapping(value="/getList",produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
    @ApiOperation(value="单位列表", notes = "查询数据列表，支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "unitInfoId", value = "当前用户的单位信息", paramType = "query")
    })
    public PageInfo<BizUnitInfo> getList(Integer pageNum, Integer pageSize, String unitInfoId ,HttpServletRequest request, BizUnitInfo unitInfo) {

        List<BizUnitInfo> list = unitInfoService.queryByExample(pageNum, pageSize, unitInfoId, unitInfo);
        PageInfo<BizUnitInfo> pageInfo = new PageInfo<BizUnitInfo>(list);
        return pageInfo;
    }

    /**
     * 单位信息下拉 查询单位类型

     * @return

     */
    @RequestMapping(value="/getTreeList",produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
    @ApiOperation(value="单位列表下拉", notes = "查询数据单位列表下拉")
    public List<BizUnitInfo> getTreeList() {
        List<BizUnitInfo> list = unitInfoService.getTreeList();
        return list;
    }



    /**
     * 根据id查询
     * @param id 主键
     * @return
     */
    @RequestMapping(value="/getById", produces = MediaType.APPLICATION_JSON_VALUE,method=RequestMethod.GET)
    @ApiOperation(value="根据id查找信息", notes = "根据id查找")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "id", paramType = "query")
    })
    public BizUnitInfo getById(String id) {
        return unitInfoService.getById(id);
    }


    /**
     * 获取单位信息
     *
     * @author ZeroLiYi
     * @date  2024/04/28 10:13
     */
    @ApiOperation("获取单位信息")
    @RequestMapping(value="/getOrg", produces = MediaType.APPLICATION_JSON_VALUE,method=RequestMethod.GET)
    @ApiImplicitParams({
            @ApiImplicitParam(name = "dwdm", value = "单位代码", paramType = "query")

    })
    public BizUnitInfo getOrg(String dwdm) {

        BizUnitInfo  bizUnitInfo= unitInfoService.getOrg(dwdm);

        return bizUnitInfo;

    }
	
    /**
     * 
     * 获取所有单位信息
     * @return
     */
    @RequestMapping(value="/getAllUnitInfo",produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
    @ApiOperation(value="单位列表", notes = "查询数据无分页")
    public List<BizUnitInfo> getAllUnitInfo() {

        return unitInfoService.getAllUnitInfo();
    }
	

}
